@@ -267,9 +267,10 @@ class Calculation(models.Model):
             incar += '\n#= LDA+U Fields =#\n'
             incar += ' LDAU = .TRUE.\n'
             incar += ' LDAUPRINT = 1\n'
-            uvals = ' '.join(str(hub.u) for hub in self.hubbards)
-            jvals = ' '.join('0' for hub in self.hubbards)
-            lvals = ' '.join(str(hub.l) for hub in self.hubbards)
+            hubbards = sorted(self.hubbards, key=lambda x: x.element_id)
+            uvals = ' '.join(str(hub.u) for hub in hubbards)
+            jvals = ' '.join('0' for hub in hubbards)
+            lvals = ' '.join(str(hub.l) for hub in hubbards)
             incar += ' LDAUU = %s\n' % uvals
             incar += ' LDAUJ = %s\n' % jvals
             incar += ' LDAUL = %s\n' % lvals
@@ -886,7 +887,7 @@ class Calculation(models.Model):
 
     def read_stdout(self, filename='stdout.txt'):
         if not os.path.exists('%s/%s' % (self.path, filename)):
-            raise VaspError('%s does not exist!' % filename)
+            return []
         stdout = open('%s/%s' % (self.path, filename)).read()
         errors = []
         if 'Error reading item' in stdout:
